/***********************************************************************
 *
 * FileName:
 *		PnpFtp.h
 *
 * Description:
 *    Declaration of FTP functions for "Palm Network Programming"
 *    FTP Client sample application.
 *
 * Note:
 *    Because this is example code, most of the error checking and safety
 *    measures (such as setting unlocked pointers to NULL) have been removed.
 *    This would need to be added back for production-ready code.
 *
 * Copyright  2000, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

#ifndef __PNPFTP_H__
#define __PNPFTP_H__

// Standard application definitions
#include "PnpDefs.h"
#include "GBuf.h"
#include <NetMgr.h>

// --------------------------------------------------------------------
// Public constant declarations
// --------------------------------------------------------------------

// FTP Operation codes. 
typedef enum
{
  kOpCodeCmdUser = 0,
  kOpCodeCmdPass,
  kOpCodeCmdQuit,
  kOpCodeNone = 0x8000,
  kOpCodeSktConnect,
  kOpCodeSktDisconnect
} PnpFtpOpCode;

// --------------------------------------------------------------------
// Public structure declarations
// --------------------------------------------------------------------
typedef struct {
   Boolean isNetConnect;      // Are we connected to network.
   NetSocketRef ctrlSocket;   // Control socket reference.
   GBufHandle ctrlInBufH;         // Buffer for receiving data.
   GBufHandle ctrlOutBufH;        // Buffer for sending data.
} PnpFtpInfoType, * PnpFtpInfoPtr;

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   PnpFtpInit:
   Initialize FTP library.
   Params:  infoP    Pointer to FTP Session information.
   Returns: 0        Success.
            <0       Error code.
*/
Err PnpFtpInit (PnpFtpInfoPtr infoP);

/*
   PnpFtpTerm:
   Terminate FTP library.
   Params:  infoP    Pointer to FTP Session information.
   Returns: 0        Success.
            <0       Error code.
*/
Err PnpFtpTerm (PnpFtpInfoPtr infoP);

/*
   PnpFtpLogin:
   Login to the FTP server.
   Params:  infoP    FTP Session object.
            svrP     Name of server to login to.
            usrP     User name to login with, or NULL for anonymous.
            passP    Password for User account, or NULL for anonymous.
   Returns: 0        Success.
            < 0      Error.
*/
Err PnpFtpLogin (PnpFtpInfoPtr infoP, Char* svrP, Char* usrP, Char* passP);

/*
   PnpFtpLogout:
   Logout from FTP Server.
   Params:  infoP    FTP Session object.
   Returns: 0        Success.
            < 0      Error.
*/
Err PnpFtpLogout (PnpFtpInfoPtr infoP);

/*
   PnpFtpIsLogin:
   Check if the we are logged in to the FTP server.
   Params:  infoP    FTP Session information.
   Returns: true     Logged in to FTP server.
            false    Not logged in to FTP server.
*/
Boolean PnpFtpIsLogin (PnpFtpInfoPtr infoP);

#endif	// __PNPFTP_H__
