/***********************************************************************
 *
 * FileName:
 *		GData.h
 *
 * Description:
 *    Declarations for GLib database record support.
 *
 * Copyright  2000, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

#ifndef __GDATA_H__
#define __GDATA_H__

// Standard application definitions
#include "GDefs.h"

// --------------------------------------------------------------------
// Public constant declarations
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// Public typedef declarations
// --------------------------------------------------------------------
typedef struct GDataType GDataType, *GDataPtr;

// --------------------------------------------------------------------
// Public structure declarations
// --------------------------------------------------------------------
struct GDataType
{
   UInt16 recordIndex;
   MemHandle recordH;
   UInt16 recordSize;
   UInt16 recordLength;
   Boolean canEdit;
};

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   GDtaCreate:
   Open a Palm database. If the database does not exist,
   create it.
   Params:  dataP       Database/record information.
            creatorId   Creator id of database to open.
            name        Name of database to open.
   Returns: 0           Success.
            <0          Error code.
*/
Err GDtaOpen (GDataPtr dataP, UInt32 creatorId, Char* name);

/*
   GDtaClose:
   Close the Database.
   Params:  dataP       Database/record information.
   Returns: 0           Success.
            <0          Error code.
*/
Err GDtaClose (GDataPtr dataP);

/*
   GDtaEmpty:
   Remove all records from a Database.
   Params:  dataP       Database/record information.
   Returns: 0           Success.
            <0          Error code.
*/
Err GDtaEmpty (GDataPtr dataP);

/*
   GDtaNumRecords:
   Get the number of records in the database.
   Params:  dataP       Database/record information.
   Returns: >=0         Number of entries on the queue.
*/
UInt16 GDtaNumRecords (GDataPtr dbP);

/*
   GDtaAppendRecord:
   Append a record to database.
   Params:  dataP       Database/record information.
            headerP     Record header, NULL if none.
            headerSize  Size of record header, 0 if none.
   Returns: 0           Success.
            <0          Error
*/
Err GDtaAppendRecord (GDataPtr dataP, UInt16 headerSize);

/*
   GDtaResizeRecord:
   Resize a record in the database.
   Params:  dataP       Database/record information.
            newSize     Requested new size.
   Returns: 0           Success
            <0          Error
*/
Err GDtaResizeRecord (GDataPtr dataP, UInt16 newSize);

/*
   GDtaQueryRecord:
   Retrieve the record from the database. The record is
   read only.
   Params:  dataP       Database/record information.
            recordIndex Index of record to retrieve.
   Returns: 0           Success
            <0          Error
*/
Int16 GDtaQueryRecord (GDataPtr dataP, UInt16 recordIndex);

/*
   GDtaReleaseRecord:
   Release a record.
   Params:  dataP       Database/record information.
   Returns: 0           Success.
            <0          Error.
*/
Err GDtaReleaseRecord (GDataPtr dataP);

#endif	// __GQUEUE_H__
