#ifndef __GLOG_H__
#define __GLOG_H__

// Standard application definitions
#include "GDefs.h"
#include "DataMgr.h"

// --------------------------------------------------------------------
// Public constant declarations
// --------------------------------------------------------------------
#define glogNil dmAllCategories

// --------------------------------------------------------------------
// Public typedef declarations
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// Public structure declarations
// --------------------------------------------------------------------
typedef struct tagGLog
{
   UInt32 creatorID;
   DmOpenRef dbR;
   Char* textP;
} GLog, * GLogPtr;

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   GLogInit:
   Initialize logging session.
   Params:  logP        GLog instance.
            creatorID   Creator ID for log client.
   Returns: 0           Success.
            <0          Error code.
*/
Err GLogInit (GLogPtr logP, UInt32 creatorID);

/*
   GLogTerm:
   Terminate logging subsystem.
   Params:  logP     GLog instance.
   Returns: 0        Success.
            <0       Error code.
*/
Err GLogTerm (GLogPtr logP);

/*
   GLogNumEntries:
   Get the number of entries in a log.
   Params:  logP     GLog instance.
            logID    Index of log.
   Returns: >=0      Number of entries in log.
            <0       Error.
*/
Int16 GLogNumEntries (GLogPtr logP, UInt16 logID);

/*
   GLogGetEntry:
   Retrieve an entry from the log.
   Params:  logP           GLog instance.
            logID          ID of log.
            entryIndex     Index of entry in log.
            textP          Out-param for log entry.
            sizeP          [in]  Max size of textP.
                           [out] Number of characters copied to textP.
   Returns: 0              Success.
            <0             Error.
*/
Err GLogGetEntry (GLogPtr logP, UInt16 logID, UInt16 entryIndex, Char* textP, UInt16* sizeP);

/*
   GLogGetEntryTime:
   Retrieve the time an entry was written to the log.
   Params:  logP            GLog Instance.
            logID           ID of log.
            entryIndex      Index of log entry.
            timeP           Out-param for time of log entry.
   Returns: 0               Success.
            !0              Error.
*/
Err GLogGetEntryTime (GLogPtr logP, UInt16 logID, UInt16 entryIndex, UInt32* timeP);
                          
/*
   GLogAddEntry:
   Add an entry to the log.
   Params:  logP           GLog instance.
            logID          ID of log.
            text           Text to draw.
   Returns: 0              Success.
            <0             Error.
*/
Err GLogAddEntry (GLogPtr logP, UInt16 logID, Char* text);

/*
   GLogPurge:
   Purge all items from the log.
   Params:  logP     GLog instance
            logID    Category of log to purge.
   Returns: 0        Success.
            <0       Error.
*/
Err GLogPurge (GLogPtr logP, UInt16 logID);

#endif	// __GLOG_H__

