/***********************************************************************
 *
 * FileName:
 *		GUnix.h
 *
 * Description:
 *    Declarations for GLib UNIX function support.
 *
 * Copyright  2000, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

#ifndef __GUNIX_H__
#define __GUNIX_H__

// Standard application definitions
#include "GDefs.h"

// --------------------------------------------------------------------
// Public constant declarations
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// Public typedef declarations
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// Public structure declarations
// --------------------------------------------------------------------

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   GTimCTime:
   Get the current time in Unix ASCII time format.
   Params:  timeString  Out-param for time string
            timeLen     Size of timeString.
   Returns: 0           Success.
            <0          Error code.
*/
Err GUnx_ctime (

/*
   GDtaClose:
   Close the Database.
   Params:  dataP       Database/record information.
   Returns: 0           Success.
            <0          Error code.
*/
Err GDtaClose (GUnixPtr dataP);

/*
   GDtaEmpty:
   Remove all records from a Database.
   Params:  dataP       Database/record information.
   Returns: 0           Success.
            <0          Error code.
*/
Err GDtaEmpty (GUnixPtr dataP);

/*
   GDtaNumRecords:
   Get the number of records in the database.
   Params:  dataP       Database/record information.
   Returns: >=0         Number of entries on the queue.
*/
UInt16 GDtaNumRecords (GUnixPtr dbP);

/*
   GDtaAppendRecord:
   Append a record to database.
   Params:  dataP       Database/record information.
            headerP     Record header, NULL if none.
            headerSize  Size of record header, 0 if none.
   Returns: 0           Success.
            <0          Error
*/
Err GDtaAppendRecord (GUnixPtr dataP, UInt16 headerSize);

/*
   GDtaResizeRecord:
   Resize a record in the database.
   Params:  dataP       Database/record information.
            newSize     Requested new size.
   Returns: 0           Success
            <0          Error
*/
Err GDtaResizeRecord (GUnixPtr dataP, UInt16 newSize);

/*
   GDtaQueryRecord:
   Retrieve the record from the database. The record is
   read only.
   Params:  dataP       Database/record information.
            recordIndex Index of record to retrieve.
   Returns: 0           Success
            <0          Error
*/
Int16 GDtaQueryRecord (GUnixPtr dataP, UInt16 recordIndex);

/*
   GDtaReleaseRecord:
   Release a record.
   Params:  dataP       Database/record information.
   Returns: 0           Success.
            <0          Error.
*/
Err GDtaReleaseRecord (GUnixPtr dataP);

#endif	// __GQUEUE_H__
