/***********************************************************************
 *
 * FileName:
 *		GUnix.c
 *
 * Description:
 *    Implementation of GLib Unix support.
 *
 * Copyright  2001, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

// Standard application definitions
#include "GUnix.h"

/*
   GUnx_ctime:
   Get the current time in Unix ASCII time format.
   Params:  timeString  Out-param for time string
            timeLen     Size of timeString.
   Returns: 0           Success.
            <0          Error code.
*/
Err
GUnx_ctime (Char* timeString, UInt16 timeLen)
{
   // Declare local variables.
   Err err = 0;         // Return values.
   UInt16 len;
   Char* cp, * fp;
   UInt32 nowInSeconds;
   DateTimeType dateTime;
   
   // Time length must be 25 or more.
   if (25 > timeLen)
   {
      return -1;
   }
   
   // Get the current date and time.
   nowInSeconds = TimGetSeconds ();
   TimSecondsToDateTime (nowInSeconds, &dateTime);
   
   // What we want is: WWW MMM DD, YYYY HH:MM:SS
   //                 "WWW" is weekday.
   DateToDOWDMFormat (dateTime.month, dateTime.day, dateTime.year, dfMDYLongWithComma, timeString);

   // Okay, so now we have WWW MMM DD, YYYY
   
   // Add a space at the end.
   StrCat (timeString, " ");
   
   // Move pointer to end of string.
   len = StrLen (timeString);
   cp = timeString + len;
   
   // Append the hour.
   fp = dateTime.hour < 10 ? "0%i:" : "%i:";
   StrPrintF (cp, fp, dateTime.hour);
   
   // Update end of string pointer.   
   len = StrLen (cp);
   cp += len;
   
   // Append the minute.
   fp = dateTime.minute < 10 ? "0%i:" : "%i:";
   StrPrintF (cp, fp, dateTime.minute);
   
   // Update end of string pointer.
   len = StrLen (cp);
   cp += len;
   
   // Append the seconds.
   fp = dateTime.second < 10 ? "0%i " : "%i ";
   StrPrintF (cp, fp, dateTime.second);
   
   // Update end of string pointer.
   len = StrLen (cp);
   cp += len;
   
   return 0;
}
